# Run all tests for gphys package
#  
# Author: jefferis
###############################################################################

library(testthat)
library(dendroextras)
test_check("dendroextras")

